==> colourvalues_0.2.2.tar.gz: colourvalues/inst/include/colourvalues/palettes/blue2red.hpp <==
#ifndef R_COLOURVALUES_BLUE2RED_H
#define R_COLOURVALUES_BLUE2RED_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector blue2red_red = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1
  };

  const Rcpp::NumericVector blue2red_green = {
    0,0.00784313725490196,0.0156862745098039,0.0235294117647059,
    0.0313725490196078,0.0392156862745098,0.0470588235294118,0.0549019607843137,
    0.0627450980392157,0.0705882352941176,0.0784313725490196,0.0862745098039216,
    0.0941176470588235,0.101960784313725,0.109803921568627,0.117647058823529,
    0.125490196078431,0.133333333333333,0.141176470588235,0.149019607843137,
    0.156862745098039,0.164705882352941,0.172549019607843,0.180392156862745,
    0.188235294117647,0.196078431372549,0.203921568627451,0.211764705882353,
    0.219607843137255,0.227450980392157,0.235294117647059,0.243137254901961,
    0.250980392156863,0.258823529411765,0.266666666666667,0.274509803921569,
    0.282352941176471,0.290196078431373,0.298039215686275,0.305882352941176,
    0.313725490196078,0.32156862745098,0.329411764705882,0.337254901960784,
    0.345098039215686,0.352941176470588,0.36078431372549,0.368627450980392,
    0.376470588235294,0.384313725490196,0.392156862745098,0.4,
    0.407843137254902,0.415686274509804,0.423529411764706,0.431372549019608,
    0.43921568627451,0.447058823529412,0.454901960784314,0.462745098039216,
    0.470588235294118,0.47843137254902,0.486274509803922,0.494117647058824,
    0.501960784313725,0.505882352941176,0.513725490196078,0.52156862745098,
    0.529411764705882,0.537254901960784,0.545098039215686,0.552941176470588,
    0.56078431372549,0.568627450980392,0.576470588235294,0.584313725490196,
    0.592156862745098,0.6,0.607843137254902,0.615686274509804,
    0.623529411764706,0.631372549019608,0.63921568627451,0.647058823529412,
    0.654901960784314,0.662745098039216,0.670588235294118,0.67843137254902,
    0.686274509803922,0.694117647058824,0.701960784313725,0.709803921568627,
    0.717647058823529,0.725490196078431,0.733333333333333,0.741176470588235,
    0.749019607843137,0.756862745098039,0.764705882352941,0.772549019607843,
    0.780392156862745,0.788235294117647,0.796078431372549,0.803921568627451,
    0.811764705882353,0.819607843137255,0.827450980392157,0.835294117647059,
    0.843137254901961,0.850980392156863,0.858823529411765,0.866666666666667,
    0.874509803921569,0.882352941176471,0.890196078431372,0.898039215686275,
    0.905882352941176,0.913725490196078,0.92156862745098,0.929411764705882,
    0.937254901960784,0.945098039215686,0.952941176470588,0.96078431372549,
    0.968627450980392,0.976470588235294,0.984313725490196,0.992156862745098,
    1,0.992156862745098,0.984313725490196,0.976470588235294,
    0.968627450980392,0.96078431372549,0.952941176470588,0.945098039215686,
    0.937254901960784,0.929411764705882,0.92156862745098,0.913725490196078,
    0.905882352941176,0.898039215686275,0.890196078431372,0.882352941176471,
    0.874509803921569,0.866666666666667,0.858823529411765,0.850980392156863,
    0.843137254901961,0.835294117647059,0.827450980392157,0.819607843137255,
    0.811764705882353,0.803921568627451,0.796078431372549,0.788235294117647,
    0.780392156862745,0.772549019607843,0.764705882352941,0.756862745098039,
    0.749019607843137,0.741176470588235,0.733333333333333,0.725490196078431,
    0.717647058823529,0.709803921568627,0.701960784313725,0.694117647058824,
    0.686274509803922,0.67843137254902,0.670588235294118,0.662745098039216,
    0.654901960784314,0.647058823529412,0.63921568627451,0.631372549019608,
    0.623529411764706,0.615686274509804,0.607843137254902,0.6,
    0.592156862745098,0.584313725490196,0.576470588235294,0.568627450980392,
    0.56078431372549,0.552941176470588,0.545098039215686,0.537254901960784,
    0.529411764705882,0.52156862745098,0.513725490196078,0.505882352941176,
    0.494117647058824,0.486274509803922,0.47843137254902,0.470588235294118,
    0.462745098039216,0.454901960784314,0.447058823529412,0.43921568627451,
    0.431372549019608,0.423529411764706,0.415686274509804,0.407843137254902,
    0.4,0.392156862745098,0.384313725490196,0.376470588235294,
    0.368627450980392,0.36078431372549,0.352941176470588,0.345098039215686,
    0.337254901960784,0.329411764705882,0.32156862745098,0.313725490196078,
    0.305882352941176,0.298039215686275,0.290196078431373,0.282352941176471,
    0.274509803921569,0.266666666666667,0.258823529411765,0.250980392156863,
    0.243137254901961,0.235294117647059,0.227450980392157,0.219607843137255,
    0.211764705882353,0.203921568627451,0.196078431372549,0.188235294117647,
    0.180392156862745,0.172549019607843,0.164705882352941,0.156862745098039,
    0.149019607843137,0.141176470588235,0.133333333333333,0.125490196078431,
    0.117647058823529,0.109803921568627,0.101960784313725,0.0941176470588235,
    0.0862745098039216,0.0784313725490196,0.0705882352941176,0.0627450980392157,
    0.0549019607843137,0.0470588235294118,0.0392156862745098,0.0313725490196078,
    0.0235294117647059,0.0156862745098039,0.00784313725490196,0
  };

  const Rcpp::NumericVector blue2red_blue = {
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

const Rcpp::List blue2red = Rcpp::List::create(
  _["r"] = blue2red_red,
  _["g"] = blue2red_green,
  _["b"] = blue2red_blue
);
} // namespace palette
} // namepsace colourvalues

#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/blue2red.hpp <==
#ifndef R_COLOURVALUES_BLUE2RED_H
#define R_COLOURVALUES_BLUE2RED_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector blue2red_red = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1
  };

  const Rcpp::NumericVector blue2red_green = {
    0,0.00784313725490196,0.0156862745098039,0.0235294117647059,
    0.0313725490196078,0.0392156862745098,0.0470588235294118,0.0549019607843137,
    0.0627450980392157,0.0705882352941176,0.0784313725490196,0.0862745098039216,
    0.0941176470588235,0.101960784313725,0.109803921568627,0.117647058823529,
    0.125490196078431,0.133333333333333,0.141176470588235,0.149019607843137,
    0.156862745098039,0.164705882352941,0.172549019607843,0.180392156862745,
    0.188235294117647,0.196078431372549,0.203921568627451,0.211764705882353,
    0.219607843137255,0.227450980392157,0.235294117647059,0.243137254901961,
    0.250980392156863,0.258823529411765,0.266666666666667,0.274509803921569,
    0.282352941176471,0.290196078431373,0.298039215686275,0.305882352941176,
    0.313725490196078,0.32156862745098,0.329411764705882,0.337254901960784,
    0.345098039215686,0.352941176470588,0.36078431372549,0.368627450980392,
    0.376470588235294,0.384313725490196,0.392156862745098,0.4,
    0.407843137254902,0.415686274509804,0.423529411764706,0.431372549019608,
    0.43921568627451,0.447058823529412,0.454901960784314,0.462745098039216,
    0.470588235294118,0.47843137254902,0.486274509803922,0.494117647058824,
    0.501960784313725,0.505882352941176,0.513725490196078,0.52156862745098,
    0.529411764705882,0.537254901960784,0.545098039215686,0.552941176470588,
    0.56078431372549,0.568627450980392,0.576470588235294,0.584313725490196,
    0.592156862745098,0.6,0.607843137254902,0.615686274509804,
    0.623529411764706,0.631372549019608,0.63921568627451,0.647058823529412,
    0.654901960784314,0.662745098039216,0.670588235294118,0.67843137254902,
    0.686274509803922,0.694117647058824,0.701960784313725,0.709803921568627,
    0.717647058823529,0.725490196078431,0.733333333333333,0.741176470588235,
    0.749019607843137,0.756862745098039,0.764705882352941,0.772549019607843,
    0.780392156862745,0.788235294117647,0.796078431372549,0.803921568627451,
    0.811764705882353,0.819607843137255,0.827450980392157,0.835294117647059,
    0.843137254901961,0.850980392156863,0.858823529411765,0.866666666666667,
    0.874509803921569,0.882352941176471,0.890196078431372,0.898039215686275,
    0.905882352941176,0.913725490196078,0.92156862745098,0.929411764705882,
    0.937254901960784,0.945098039215686,0.952941176470588,0.96078431372549,
    0.968627450980392,0.976470588235294,0.984313725490196,0.992156862745098,
    1,0.992156862745098,0.984313725490196,0.976470588235294,
    0.968627450980392,0.96078431372549,0.952941176470588,0.945098039215686,
    0.937254901960784,0.929411764705882,0.92156862745098,0.913725490196078,
    0.905882352941176,0.898039215686275,0.890196078431372,0.882352941176471,
    0.874509803921569,0.866666666666667,0.858823529411765,0.850980392156863,
    0.843137254901961,0.835294117647059,0.827450980392157,0.819607843137255,
    0.811764705882353,0.803921568627451,0.796078431372549,0.788235294117647,
    0.780392156862745,0.772549019607843,0.764705882352941,0.756862745098039,
    0.749019607843137,0.741176470588235,0.733333333333333,0.725490196078431,
    0.717647058823529,0.709803921568627,0.701960784313725,0.694117647058824,
    0.686274509803922,0.67843137254902,0.670588235294118,0.662745098039216,
    0.654901960784314,0.647058823529412,0.63921568627451,0.631372549019608,
    0.623529411764706,0.615686274509804,0.607843137254902,0.6,
    0.592156862745098,0.584313725490196,0.576470588235294,0.568627450980392,
    0.56078431372549,0.552941176470588,0.545098039215686,0.537254901960784,
    0.529411764705882,0.52156862745098,0.513725490196078,0.505882352941176,
    0.494117647058824,0.486274509803922,0.47843137254902,0.470588235294118,
    0.462745098039216,0.454901960784314,0.447058823529412,0.43921568627451,
    0.431372549019608,0.423529411764706,0.415686274509804,0.407843137254902,
    0.4,0.392156862745098,0.384313725490196,0.376470588235294,
    0.368627450980392,0.36078431372549,0.352941176470588,0.345098039215686,
    0.337254901960784,0.329411764705882,0.32156862745098,0.313725490196078,
    0.305882352941176,0.298039215686275,0.290196078431373,0.282352941176471,
    0.274509803921569,0.266666666666667,0.258823529411765,0.250980392156863,
    0.243137254901961,0.235294117647059,0.227450980392157,0.219607843137255,
    0.211764705882353,0.203921568627451,0.196078431372549,0.188235294117647,
    0.180392156862745,0.172549019607843,0.164705882352941,0.156862745098039,
    0.149019607843137,0.141176470588235,0.133333333333333,0.125490196078431,
    0.117647058823529,0.109803921568627,0.101960784313725,0.0941176470588235,
    0.0862745098039216,0.0784313725490196,0.0705882352941176,0.0627450980392157,
    0.0549019607843137,0.0470588235294118,0.0392156862745098,0.0313725490196078,
    0.0235294117647059,0.0156862745098039,0.00784313725490196,0
  };

  const Rcpp::NumericVector blue2red_blue = {
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

  // inline Rcpp::DataFrame blue2red() {
  //   return Rcpp::DataFrame::create(
  //     _["r"] = blue2red_red,
  //     _["g"] = blue2red_green,
  //     _["b"] = blue2red_blue
  //   );
  // }
} // namespace palette
} // namepsace colourvalues

#endif
